@@ -367,7 +367,7 @@ class WordType(models.Model):
     def figureStresses(self):
         guessed = guessStress(self.getUR(blick_style=True))
         stresses = re.sub(r'\D',r'',guessed)
-        syls = self.UR.filter(Syllabic=True)
+        syls = self.underlying_set.filter(SegmentType__Syllabic=True)
         for i in range(len(syls)):
             syls[i].Stressed = int(stresses[i])
             syls[i].save()
